.. _bibliography:

Bibliography
============

.. _Gil76:

Daniel Gillespie. A general method for numerically simulating the
stochastic time evolution of coupled chemical reactions. Journal of
Computational Physics **22**, pp.403-–434. 1976.

.. _Gil77:

Daniel Gillespie. Exact stochastic simulation of coupled chemical
reactions. Journal of Physical Chemistry **81** (25),
pp.2340-–2361. 1977.

.. _New02:
M.E.J. Newman. `Spread of epidemic disease on networks
<http://dx.doi.org/10.1103/PhysRevE.66.016128>`_. Physical Review E
**66**. July 2002.
